---
name: Asking for help
about: If you need help using Mesa-LLM, you should post in https://github.com/mesa/mesa-llm/discussions
---

<!--
    ATTENTION: Don't raise an issue here!
    If you need help, ask in https://github.com/mesa/mesa-llm/discussions
-->